@@ -1,14 +1,17 @@
 import os
 
+
 class CViseError(Exception):
     pass
 
+
 class PrerequisitesNotFoundError(CViseError):
     def __init__(self, missing):
         self.missing = missing
 
     def __str__(self):
-        return "Missing prerequisites for passes {}!".format(", ".join(self.missing))
+        return 'Missing prerequisites for passes {}!'.format(', '.join(self.missing))
+
 
 class UnknownArgumentError(CViseError):
     def __init__(self, pass_, arg):
@@ -18,6 +21,7 @@ class UnknownArgumentError(CViseError):
     def __str__(self):
         return "The argument '{}' is not valid for pass '{}'!".format(self.arg, self.pass_.__name__)
 
+
 class InvalidFileError(CViseError):
     def __init__(self, path, error):
         self.path = path
@@ -25,21 +29,23 @@ class InvalidFileError(CViseError):
 
     def _get_error_name(self):
         if self.error == os.R_OK:
-            return "read"
+            return 'read'
         elif self.error == os.W_OK:
-            return "written"
+            return 'written'
         elif self.error == os.X_OK:
-            return "executed"
+            return 'executed'
         elif self.error == os.F_OK:
-            return "accessed"
+            return 'accessed'
 
     def __str__(self):
         return "The specified file '{}' cannot be {}!".format(self.path, self._get_error_name())
 
+
 class InvalidTestCaseError(InvalidFileError):
     def __str__(self):
         return "The specified test case '{}' cannot be {}!".format(self.path, self._get_error_name())
 
+
 class InvalidInterestingnessTestError(InvalidFileError):
     def __init__(self, path):
         super().__init__(path, None)
@@ -47,6 +53,7 @@ class InvalidInterestingnessTestError(InvalidFileError):
     def __str__(self):
         return "The specified interestingness test '{}' cannot be executed!".format(self.path)
 
+
 class ZeroSizeError(CViseError):
     def __init__(self, test_cases):
         super().__init__()
@@ -54,9 +61,9 @@ class ZeroSizeError(CViseError):
 
     def __str__(self):
         if len(self.test_cases) == 1:
-            message = "The file being reduced has reached zero size; "
+            message = 'The file being reduced has reached zero size; '
         else:
-            message = "All files being reduced have reached zero size; "
+            message = 'All files being reduced have reached zero size; '
 
         message += """our work here is done.
 
@@ -65,12 +72,15 @@ making sure that your interestingness test does not find files like
 this to be interesting."""
         return message
 
+
 class PassOptionError(CViseError):
     pass
 
+
 class MissingPassGroupsError(CViseError):
     def __str__(self):
-        return "Could not find a directory with definitions for pass groups!"
+        return 'Could not find a directory with definitions for pass groups!'
+
 
 class PassBugError(CViseError):
     MSG = """***************************************************
@@ -95,6 +105,7 @@ and creating an issue at https://github.com/marxin/cvise/issues and we will try
     def __str__(self):
         return self.MSG.format(self.current_pass, self.problem, self.state, self.crash_dir)
 
+
 class InsaneTestCaseError(CViseError):
     def __init__(self, test_cases, test):
         super().__init__()
@@ -114,9 +125,9 @@ words, running these commands:
   {test}
   echo $?
 
-should result in "0" being echoed to the terminal.
+should result in '0' being echoed to the terminal.
 Please ensure that the test script takes no arguments; it should be hard-coded to refer
 to the same file that is passed as an argument to C-Vise.
 
-See "cvise.py --help" for more information.""".format(test_cases=" ".join(self.test_cases), test=self.test)
+See 'cvise.py --help' for more information.""".format(test_cases=' '.join(self.test_cases), test=self.test)
         return message
